summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/purify/chrome_tests.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/purify/chrome_tests.py b/tools/purify/chrome_tests.py
index b8c9a03..9678dc4 100644
--- a/tools/purify/chrome_tests.py
+++ b/tools/purify/chrome_tests.py
@@ -354,8 +354,8 @@ class ChromeTests:
# may get skipped in the current cycle. For more discussion on this issue,
# see http://codereview.chromium.org/149600.
- # Break UI tests into 30 slices so we have about 30 minutes per run.
- batch_count = 30
+ # Break UI tests into 16 slices so we have about 30-40 minutes per run.
+ batch_count = 16
batch_index = 0
batch_index_file = os.path.join(os.environ["TEMP"],
"purify_ui_batch_index.txt")